==> alluxio-shaded-client-2.1.2-sources.jar: alluxio/cli/CommandUtils.java <==
/*
 * The Alluxio Open Foundation licenses this work under the Apache License, version 2.0
 * (the "License"). You may not use this work except in alluxio.shaded.client.com.liance with the License, which is
 * available at www.apache.alluxio.shaded.client.org.licenses/LICENSE-2.0
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied, as more fully set forth in the License.
 *
 * See the NOTICE file distributed with this work for information regarding copyright ownership.
 */

package alluxio.cli;

import alluxio.exception.ExceptionMessage;
import alluxio.exception.status.InvalidArgumentException;
import alluxio.util.CommonUtils;

import alluxio.shaded.client.org.apache.alluxio.shaded.client.com.ons.cli.CommandLine;
import alluxio.shaded.client.org.reflections.Reflections;

import java.lang.reflect.Modifier;
import java.util.HashMap;
import java.util.Map;

import alluxio.shaded.client.javax.annotation.concurrent.ThreadSafe;

/**
 * Class for convenience methods used by instances of {@link Command}.
 */
@ThreadSafe
public final class CommandUtils {

  private CommandUtils() {} // prevent instantiation

  /**
   * Get instances of all subclasses of {@link Command} in a sub-package called "alluxio.shaded.client.com.and" the given
   * package.
   *
   * @param pkgName package prefix to look in
   * @param classArgs type of args to instantiate the class
   * @param objectArgs args to instantiate the class
   * @return a mapping from alluxio.shaded.client.com.and name to alluxio.shaded.client.com.and instance
   */
  public static Map<String, Command> loadCommands(String pkgName, Class[] classArgs,
      Object[] objectArgs) {
    Map<String, Command> alluxio.shaded.client.com.andsMap = new HashMap<>();
    Reflections reflections = new Reflections(Command.class.getPackage().getName());
    for (Class<? extends Command> cls : reflections.getSubTypesOf(Command.class)) {
      // Add alluxio.shaded.client.com.ands from <pkgName>.alluxio.shaded.client.com.and.*
      if (cls.getPackage().getName().equals(pkgName + ".alluxio.shaded.client.com.and")
          && !Modifier.isAbstract(cls.getModifiers())) {
        // Only instantiate a concrete class
        Command cmd = CommonUtils.createNewClassInstance(cls, classArgs, objectArgs);
        alluxio.shaded.client.com.andsMap.put(cmd.getCommandName(), cmd);
      }
    }
    return alluxio.shaded.client.com.andsMap;
  }

  /**
   * Checks the number of non-option arguments equals n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number does not equal n
   */
  public static void checkNumOfArgsEquals(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length != n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }

  /**
   * Checks the number of non-option arguments is no less than n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number is smaller than n
   */
  public static void checkNumOfArgsNoLessThan(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length < n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM_INSUFFICIENT
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }

  /**
   * Checks the number of non-option arguments is no more than n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number is greater than n
   */
  public static void checkNumOfArgsNoMoreThan(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length > n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM_TOO_MANY
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }
}

==> alluxio-shaded-client-2.2.2-2-sources.jar: alluxio/cli/CommandUtils.java <==
/*
 * The Alluxio Open Foundation licenses this work under the Apache License, version 2.0
 * (the "License"). You may not use this work except in alluxio.shaded.client.com.liance with the License, which is
 * available at www.apache.alluxio.shaded.client.org.licenses/LICENSE-2.0
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied, as more fully set forth in the License.
 *
 * See the NOTICE file distributed with this work for information regarding copyright ownership.
 */

package alluxio.cli;

import alluxio.exception.ExceptionMessage;
import alluxio.exception.status.InvalidArgumentException;
import alluxio.util.CommonUtils;

import alluxio.shaded.client.org.apache.alluxio.shaded.client.com.ons.cli.CommandLine;
import alluxio.shaded.client.org.reflections.Reflections;

import java.alluxio.shaded.client.io.IOException;
import java.lang.reflect.Modifier;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import alluxio.shaded.client.javax.annotation.Nullable;
import alluxio.shaded.client.javax.annotation.concurrent.ThreadSafe;

/**
 * Class for convenience methods used by instances of {@link Command}.
 */
@ThreadSafe
public final class CommandUtils {

  private CommandUtils() {} // prevent instantiation

  /**
   * Get instances of all subclasses of {@link Command} in a sub-package called "alluxio.shaded.client.com.and" the given
   * package.
   *
   * @param pkgName package prefix to look in
   * @param classArgs type of args to instantiate the class
   * @param objectArgs args to instantiate the class
   * @return a mapping from alluxio.shaded.client.com.and name to alluxio.shaded.client.com.and instance
   */
  public static Map<String, Command> loadCommands(String pkgName, Class[] classArgs,
      Object[] objectArgs) {
    Map<String, Command> alluxio.shaded.client.com.andsMap = new HashMap<>();
    Reflections reflections = new Reflections(Command.class.getPackage().getName());
    for (Class<? extends Command> cls : reflections.getSubTypesOf(Command.class)) {
      // Add alluxio.shaded.client.com.ands from <pkgName>.alluxio.shaded.client.com.and.*
      if (cls.getPackage().getName().equals(pkgName + ".alluxio.shaded.client.com.and")
          && !Modifier.isAbstract(cls.getModifiers())) {
        // Only instantiate a concrete class
        Command cmd = CommonUtils.createNewClassInstance(cls, classArgs, objectArgs);
        alluxio.shaded.client.com.andsMap.put(cmd.getCommandName(), cmd);
      }
    }
    return alluxio.shaded.client.com.andsMap;
  }

  /**
   * Checks the number of non-option arguments equals n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number does not equal n
   */
  public static void checkNumOfArgsEquals(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length != n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }

  /**
   * Checks the number of non-option arguments is no less than n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number is smaller than n
   */
  public static void checkNumOfArgsNoLessThan(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length < n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM_INSUFFICIENT
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }

  /**
   * Checks the number of non-option arguments is no more than n for alluxio.shaded.client.com.and.
   *
   * @param cmd alluxio.shaded.client.com.and instance
   * @param cl parsed alluxio.shaded.client.com.andline arguments
   * @param n an integer
   * @throws InvalidArgumentException if the number is greater than n
   */
  public static void checkNumOfArgsNoMoreThan(Command cmd, CommandLine cl, int n) throws
      InvalidArgumentException {
    if (cl.getArgs().length > n) {
      throw new InvalidArgumentException(ExceptionMessage.INVALID_ARGS_NUM_TOO_MANY
          .getMessage(cmd.getCommandName(), n, cl.getArgs().length));
    }
  }

  /**
   * Reads a list of nodes from given file name ignoring alluxio.shaded.client.com.ents and empty lines.
   * Can be used to read conf/workers or conf/masters.
   * @param confDir directory that holds the configuration
   * @param fileName name of a file that contains the list of the nodes
   * @return list of the node names, null when file fails to read
   */
  @Nullable
  public static List<String> readNodeList(String confDir, String fileName) {
    List<String> lines;
    try {
      lines = Files.readAllLines(Paths.get(confDir, fileName), StandardCharsets.UTF_8);
    } catch (IOException e) {
      System.err.format("Failed to read file %s/%s. Ignored.", confDir, fileName);
      return new ArrayList<>();
    }

    List<String> nodes = new ArrayList<>();
    for (String line : lines) {
      String node = line.trim();
      if (node.startsWith("#") || node.length() == 0) {
        continue;
      }
      nodes.add(node);
    }

    return nodes;
  }
}
